@@ -244,8 +244,8 @@ pkcs11h_getFeatures (void) {
 #if defined(ENABLE_PKCS11H_ENGINE_WIN32)
 		PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_WIN32 |
 #endif
-#if defined(ENABLE_PKCS11H_ENGINE_POLARSSL)
-		PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_POLARSSL |
+#if defined(ENABLE_PKCS11H_ENGINE_MBEDTLS)
+		PKCS11H_FEATURE_MASK_ENGINE_CRYPTO_MBEDTLS |
 #endif
 #if defined(ENABLE_PKCS11H_DEBUG)
 		PKCS11H_FEATURE_MASK_DEBUG |
